@@ -18,6 +18,7 @@
 
 #include <QByteArray>
 #include <QUrl>
+#include <QUuid>
 #include <QNetworkCookie>
 #include <QNetworkRequest>
 #include <QSslSocket>
@@ -34,6 +35,7 @@
 #include "common/utility.h"
 #include <memory>
 #include "capabilities.h"
+#include "jobqueue.h"
 
 class QSettings;
 class QNetworkReply;
@@ -42,6 +44,7 @@ class QNetworkAccessManager;
 
 namespace OCC {
 
+class CredentialManager;
 class AbstractCredentials;
 class Account;
 typedef QSharedPointer<Account> AccountPtr;
@@ -58,7 +61,7 @@ class AbstractSslErrorHandler
 {
 public:
     virtual ~AbstractSslErrorHandler() {}
-    virtual bool handleErrors(QList<QSslError>, const QSslConfiguration &conf, QList<QSslCertificate> *, AccountPtr) = 0;
+    virtual bool handleErrors(const QList<QSslError> &, const QSslConfiguration &conf, QList<QSslCertificate> *, AccountPtr) = 0;
 };
 
 /**
@@ -71,9 +74,14 @@ public:
 class OWNCLOUDSYNC_EXPORT Account : public QObject
 {
     Q_OBJECT
+    Q_PROPERTY(QString id MEMBER _id)
+    Q_PROPERTY(QString davUser MEMBER _davUser)
+    Q_PROPERTY(QString displayName MEMBER _displayName)
+    Q_PROPERTY(QUrl url MEMBER _url)
+
 public:
     static AccountPtr create();
-    ~Account();
+    ~Account() override;
 
     AccountPtr sharedFromThis();
 
@@ -90,23 +98,20 @@ public:
     void setDavDisplayName(const QString &newDisplayName);
 
 #ifndef TOKEN_AUTH_ONLY
-    QImage avatar() const;
-    void setAvatar(const QImage &img);
+    QPixmap avatar() const;
+    void setAvatar(const QPixmap &img);
 #endif
 
     /// The name of the account as shown in the toolbar
     QString displayName() const;
 
     /// The internal id of the account.
-    QString id() const;
+    Q_DECL_DEPRECATED_X("Use uuid") QString id() const;
 
     /** Server url of the account */
     void setUrl(const QUrl &url);
     QUrl url() const { return _url; }
 
-    /// Adjusts _userVisibleUrl once the host to use is discovered.
-    void setUserVisibleHost(const QString &host);
-
     /**
      * @brief The possibly themed dav path for the account. It has
      *        a trailing slash.
@@ -114,18 +119,10 @@ public:
      */
     QString davPath() const;
     void setDavPath(const QString &s) { _davPath = s; }
-    void setNonShib(bool nonShib);
 
     /** Returns webdav entry URL, based on url() */
     QUrl davUrl() const;
 
-    /** Returns the legacy permalink url for a file.
-     *
-     * This uses the old way of manually building the url. New code should
-     * use the "privatelink" property accessible via PROPFIND.
-     */
-    QUrl deprecatedPrivateLinkUrl(const QByteArray &numericFileId) const;
-
     /** Holds the accounts credentials */
     AbstractCredentials *credentials() const;
     void setCredentials(AbstractCredentials *cred);
@@ -139,16 +136,7 @@ public:
     QNetworkReply *sendRawRequest(const QByteArray &verb,
         const QUrl &url,
         QNetworkRequest req = QNetworkRequest(),
-        QIODevice *data = 0);
-
-    /** Create and start network job for a simple one-off request.
-     *
-     * More complicated requests typically create their own job types.
-     */
-    SimpleNetworkJob *sendRequest(const QByteArray &verb,
-        const QUrl &url,
-        QNetworkRequest req = QNetworkRequest(),
-        QIODevice *data = 0);
+        QIODevice *data = nullptr);
 
     /** The ssl configuration during the first connection */
     QSslConfiguration getOrCreateSslConfig();
@@ -177,9 +165,6 @@ public:
     QVariant credentialSetting(const QString &key) const;
     void setCredentialSetting(const QString &key, const QVariant &value);
 
-    /** Assign a client certificate */
-    void setCertificate(const QByteArray certficate = QByteArray(), const QString privateKey = QString());
-
     /** Access the server capabilities */
     const Capabilities &capabilities() const;
     void setCapabilities(const QVariantMap &caps);
@@ -226,13 +211,16 @@ public:
     QNetworkAccessManager *networkAccessManager();
     QSharedPointer<QNetworkAccessManager> sharedNetworkAccessManager();
 
-    /// Called by network jobs on credential errors, emits invalidCredentials()
-    void handleInvalidCredentials();
+    JobQueue *jobQueue();
+
+    QUuid uuid() const;
+
+    CredentialManager *credentialManager() const;
 
 public slots:
     /// Used when forgetting credentials
     void clearQNAMCache();
-    void slotHandleSslErrors(QNetworkReply *, QList<QSslError>);
+    void slotHandleSslErrors(QPointer<QNetworkReply>, const QList<QSslError> &);
 
 signals:
     /// Emitted whenever there's network activity
@@ -255,32 +243,29 @@ signals:
     void accountChangedAvatar();
     void accountChangedDisplayName();
 
+    void unknownConnectionState();
+
+    void requestUrlUpdate(const QUrl &newUrl);
+
 protected Q_SLOTS:
     void slotCredentialsFetched();
     void slotCredentialsAsked();
 
 private:
-    Account(QObject *parent = 0);
+    Account(QObject *parent = nullptr);
     void setSharedThis(AccountPtr sharedThis);
 
     QWeakPointer<Account> _sharedThis;
     QString _id;
+    QUuid _uuid;
     QString _davUser;
     QString _displayName;
 #ifndef TOKEN_AUTH_ONLY
-    QImage _avatarImg;
+    QPixmap _avatarImg;
 #endif
     QMap<QString, QVariant> _settingsMap;
     QUrl _url;
 
-    /** If url to use for any user-visible urls.
-     *
-     * If the server configures overwritehost this can be different from
-     * the connection url in _url. We retrieve the visible host through
-     * the ocs/v1.php/config endpoint in ConnectionValidator.
-     */
-    QUrl _userVisibleUrl;
-
     QList<QSslCertificate> _approvedCerts;
     QSslConfiguration _sslConfiguration;
     Capabilities _capabilities;
@@ -297,6 +282,9 @@ private:
     static QString _configFileName;
 
     QString _davPath; // defaults to value from theme, might be overwritten in brandings
+    JobQueue _jobQueue;
+    JobQueueGuard _queueGuard;
+    CredentialManager *_credentialManager;
     friend class AccountManager;
 };
 }
