@@ -21,6 +21,9 @@
 #include <QMetaType>
 #include <QSharedPointer>
 
+#include <set>
+
+#include <common/utility.h>
 #include <csync.h>
 
 #include <owncloudlib.h>
@@ -62,7 +65,7 @@ public:
          */
         Conflict,
 
-        FileIgnored, ///< The file is in the ignored list (or blacklisted with no retries left)
+        FileIgnored, ///< The file has an invalid name or is in the blacklisted with no retries left
         Restoration, ///< The file was restored because what should have been done was not allowed
 
         /** For errors that should only appear in the error view.
@@ -83,16 +86,27 @@ public:
          *
          * A SoftError caused by blacklisting.
          */
-        BlacklistedError
+        BlacklistedError,
+
+        /**
+         * The file is excluded by the ignore list
+         */
+        Excluded,
+
+        /** For use in an array or vector for the number of items in this enum.
+         */
+        StatusCount
     };
     Q_ENUM(Status)
 
+    static QString statusEnumDisplayName(Status s);
+
     SyncJournalFileRecord toSyncJournalFileRecordWithInode(const QString &localFileName) const;
 
     /** Creates a basic SyncFileItem from a DB record
      *
      * This is intended in particular for read-update-write cycles that need
-     * to go through a a SyncFileItem, like PollJob.
+     * to go through a a SyncFileItem.
      */
     static SyncFileItemPtr fromSyncJournalFileRecord(const SyncJournalFileRecord &rec);
 
@@ -102,7 +116,6 @@ public:
         , _direction(None)
         , _serverHasIgnoredFiles(false)
         , _hasBlacklistEntry(false)
-        , _errorMayBeBlacklisted(false)
         , _status(NoStatus)
         , _isRestoration(false)
         , _isSelectiveSync(false)
@@ -114,6 +127,7 @@ public:
         , _inode(0)
         , _previousSize(0)
         , _previousModtime(0)
+        , _relevantDirectoyInstruction(false)
     {
     }
 
@@ -232,13 +246,6 @@ public:
     /// without the status being FileIgnored.
     bool _hasBlacklistEntry BITFIELD(1);
 
-    /** If true and NormalError, this error may be blacklisted
-     *
-     * Note that non-local errors (httpErrorCode!=0) may also be
-     * blacklisted independently of this flag.
-     */
-    bool _errorMayBeBlacklisted BITFIELD(1);
-
     // Variables useful to report to the user
     Status _status BITFIELD(4);
     bool _isRestoration BITFIELD(1); // The original operation was forbidden, and this is a restoration
@@ -246,6 +253,7 @@ public:
     quint16 _httpErrorCode;
     RemotePermissions _remotePerm;
     QString _errorString; // Contains a string only in case of error
+    QString _messageString; // Contains a string only in case of hand crafted events
     QByteArray _responseTimeStamp;
     QByteArray _requestId; // X-Request-Id of the failed request
     quint32 _affectedItems; // the number of affected items by the operation on this item.
@@ -273,6 +281,9 @@ public:
 
     QString _directDownloadUrl;
     QString _directDownloadCookies;
+
+    bool _relevantDirectoyInstruction = false;
+    bool _finished = false;
 };
 
 inline bool operator<(const SyncFileItemPtr &item1, const SyncFileItemPtr &item2)
@@ -280,10 +291,18 @@ inline bool operator<(const SyncFileItemPtr &item1, const SyncFileItemPtr &item2
     return *item1 < *item2;
 }
 
-typedef QVector<SyncFileItemPtr> SyncFileItemVector;
+using SyncFileItemSet = std::set<SyncFileItemPtr>;
 }
 
+Q_DECLARE_METATYPE(OCC::SyncFileItemSet)
 Q_DECLARE_METATYPE(OCC::SyncFileItem)
 Q_DECLARE_METATYPE(OCC::SyncFileItemPtr)
 
+OWNCLOUDSYNC_EXPORT QDebug operator<<(QDebug debug, const OCC::SyncFileItem *item);
+inline QDebug operator<<(QDebug debug, const OCC::SyncFileItemPtr &item)
+{
+    return debug << item.data();
+}
+
+
 #endif // SYNCFILEITEM_H
